﻿Imports System.Globalization
Imports System.Net.Http
Imports Windows.Data.Json
Imports Windows.Devices.Geolocation
Imports Windows.Services.Maps
Imports Windows.UI.Popups
Imports Windows.UI.Xaml.Controls.Maps

Public NotInheritable Class MainPage
    Inherits Page

    Public Sub New()
        InitializeComponent()
        CultureInfo.CurrentCulture = New CultureInfo("en-en")
    End Sub

    Private Async Sub Location_Click(sender As Object, e As RoutedEventArgs)
        Dim status As GeolocationAccessStatus = Await Geolocator.RequestAccessAsync()

        If (status <> GeolocationAccessStatus.Allowed) Then
            Await New MessageDialog($"Keine Standorterkennung {status}").ShowAsync()
            Return
        End If

        Dim geoloc As Geolocator = New Geolocator()
        Dim position As Geoposition = Await geoloc.GetGeopositionAsync()

        lattitude.Text =
             position.Coordinate.Point.Position.Latitude.ToString()
        longitude.Text =
             position.Coordinate.Point.Position.Longitude.ToString()

    End Sub

    Private Async Sub Find_Click(sender As Object, e As RoutedEventArgs)
        Dim lat = Double.Parse(lattitude.Text)
        Dim lon = Double.Parse(longitude.Text)

        ' OpenStreetMap-Abfrage
        Dim client = New HttpClient()
        Dim header = "SampleApp Windows 10"

        client.DefaultRequestHeaders.UserAgent.TryParseAdd(header)

        Dim Content = Await client.GetStringAsync(New Uri($"http://nominatim.openstreetmap.org/reverse?format=json&lat={lat}&lon={lon}"))

        Dim json = JsonObject.Parse(Content)

        Dim address = $"OpenStreetMap-Abfrage:{vbCrLf}"
        address += json.GetNamedString("display_name", "<na>")

        json = json.GetNamedObject("address")

        address += $"{vbCrLf}Land: " + json.GetNamedString("country", "<na>")
        address += ", Plz: " + json.GetNamedString("postcode", "<na>")
        address += ", Strasse: " + json.GetNamedString("road", "<na>")
        address += ", Ort: " + json.GetNamedString("city", "<na>")

        address += $"{vbCrLf}Universal Windows Platform-Abfrage:{vbCrLf}"

        Dim position = New BasicGeoposition With {
            .Latitude = lat,
            .Longitude = lon
         }

        Dim geopoint = New Geopoint(position)
        Dim location = Await MapLocationFinder.FindLocationsAtAsync(geopoint)

        If (location.Status = MapLocationFinderStatus.Success) Then
            For Each place In location.Locations
                address += place.Address.FormattedAddress + vbCrLf
            Next
        End If

        textblock.Text = address

        ' Standort in Karte anzeigen und zoomen
        Dim pointOfInterest = New MapIcon With {
            .Location = geopoint,
            .Title = "Interessanter Punkt",
            .ZIndex = 0
        }

        map.MapElements.Add(pointOfInterest)

        map.Center = geopoint
        Await map.TrySetViewAsync(geopoint, 14, Nothing, Nothing, MapAnimationKind.Bow)
        ' map.ZoomLevel = 14

    End Sub

    Private Sub map_MapTapped(sender As Maps.MapControl, args As Maps.MapInputEventArgs)
        lattitude.Text = args.Location.Position.Latitude.ToString()
        longitude.Text = args.Location.Position.Longitude.ToString()
    End Sub

End Class
